@@ -5,13 +5,19 @@ import pytest
 
 from libdyson import (
     DEVICE_TYPE_360_EYE,
+    DEVICE_TYPE_PURE_COOL_LINK,
     DEVICE_TYPE_PURE_COOL_LINK_DESK,
-    DEVICE_TYPE_PURE_COOL_LINK_TOWER,
+    Dyson360Eye,
+    DysonDevice,
+    DysonPureCool,
+    DysonPureCoolLink,
     get_device,
 )
-from libdyson.dyson_360_eye import Dyson360Eye
-from libdyson.dyson_device import DysonDevice
-from libdyson.dyson_pure_cool_link import DysonPureCoolLink
+from libdyson.const import (
+    DEVICE_TYPE_PURE_COOL,
+    DEVICE_TYPE_PURE_COOL_DESK,
+    DEVICE_TYPE_PURE_HUMIDITY_COOL,
+)
 
 from . import CREDENTIAL, SERIAL
 
@@ -21,7 +27,10 @@ from . import CREDENTIAL, SERIAL
     [
         (DEVICE_TYPE_360_EYE, Dyson360Eye),
         (DEVICE_TYPE_PURE_COOL_LINK_DESK, DysonPureCoolLink),
-        (DEVICE_TYPE_PURE_COOL_LINK_TOWER, DysonPureCoolLink),
+        (DEVICE_TYPE_PURE_COOL_LINK, DysonPureCoolLink),
+        (DEVICE_TYPE_PURE_COOL, DysonPureCool),
+        (DEVICE_TYPE_PURE_COOL_DESK, DysonPureCool),
+        (DEVICE_TYPE_PURE_HUMIDITY_COOL, DysonPureCool),
     ],
 )
 def test_get_device(device_type: str, class_type: Type[DysonDevice]):
